@@ -6,15 +6,28 @@ void aster_family(int *famin, int *derivin, double *thetain, double *value);
 
 int aster_family_validate(int fam, double x, double xpred);
 
+int aster_family_validate_parent(int fam, double xpred);
+
+int aster_family_number_validate(int fam);
+
+double aster_family_origin(int fam);
+
 double aster_family_simulate(int fam, double xpred, double theta);
 
+#ifdef ASTER_OLD_STUFF
 char *aster_family_name(int fam);
+#endif /* ASTER_OLD_STUFF */
+
+void aster_default_origin(int *nindin, int *nnodein, int *fam, double *result);
 
 void aster_check_model(int *nindin, int *nnodein, int *pred, int *fam);
 
 void aster_check_model_data(int *nindin, int *nnodein, int *pred, int *fam,
     double *x, double *root);
 
+void aster_check_model_root(int *nindin, int *nnodein, int *pred, int *fam,
+    double *root);
+
 void aster_theta2phi(int *nindin, int *nnodein, int *pred, int *fam,
     double *theta, double *phi);
 
@@ -31,7 +44,7 @@ void aster_xpred(int *nindin, int *nnodein, int *pred, int *fam,
     double *x, double *root, double *xpred);
 
 void aster_ctau2tau(int *nindin, int *nnodein, int *pred, int *fam,
-    double *x, double *root, double *ctau, double *tau);
+    double *root, double *ctau, double *tau);
 
 void aster_tt2var(int *nindin, int *nnodein, int *pred, int *fam,
     double *x, double *root, double *theta, double *tau, double *var);
@@ -48,21 +61,29 @@ void aster_a_delsqpsi_m(int *nindin, int *nnodein, int *ncoefin,
 void aster_id_delsqpsi_m(int *nindin, int *nnodein, int *ncoefin, int *pred,
     int *fam, double *ctau, double *varx, double *m, double *result);
 
+#ifdef ASTER_OLD_STUFF
 void aster_rnzp(int *nin, int *len_xpred_in, int *len_mu_in,
     double *xpred, double *mu, double *result);
+#endif /* ASTER_OLD_STUFF */
 
 void aster_rktp(int *nin, int *len_xpred_in, int *len_mu_in, int *len_k_in,
     double *xpred_in, double *mu_in, int *k_in, double *result);
 
+void aster_rktnb(int *nin, int *len_xpred_in, int *len_mu_in, int *len_k_in,
+    int *len_alpha_in, double *xpred_in, double *mu_in, int *k_in,
+    double *alpha_in, double *result);
+
 void aster_simulate_data(int *nindin, int *nnodein, int *pred, int *fam,
     double *theta, double *root, double *x);
 
 void aster_mlogl_cond(int *nindin, int *nnodein, int *ncoefin, int *pred,
     int *fam, int *derivin, double *beta, double *root, double *x,
+    double *origin,
     double *modmat, double *value, double *gradient, double *hessian);
 
 void aster_mlogl_unco(int *nindin, int *nnodein, int *ncoefin, int *pred,
     int *fam, int *derivin, double *beta, double *root, double *x,
+    double *origin,
     double *modmat, double *value, double *gradient, double *hessian);
 
 void aster_fish_cond(int *nindin, int *nnodein, int *ncoefin, int *pred,
@@ -87,11 +108,24 @@ void aster_D_beta2theta2phi(int *nindin, int *nnodein, int *ncoefin,
 void aster_D_beta2phi2theta(int *nindin, int *nnodein, int *ncoefin,
     int *pred, int *fam, double *theta, double *modmat, double *gradmat);
 
-void aster_D_beta2phi2tau(int *nindin, int *nnodein, int *ncoefin, int *pred, 
-    int *fam, double *beta, double *root, double *modmat, double *gradmat);
+void aster_D_beta2phi2tau(int *nindin, int *nnodein, int *ncoefin, int *pred,
+    int *fam, double *beta, double *root, double *origin, double *modmat,
+    double *gradmat);
 
 void aster_D_beta2theta2tau(int *nindin, int *nnodein, int *ncoefin, int *pred,
     int *fam, double *beta, double *root, double *modmat, double *gradmat);
 
+void aster_clear_families(void);
+
+void aster_add_family(char **name, double *hyper, int *nhyper);
+
+void aster_get_family(int *famin, char **name, double *hyper, int *nhyper,
+    char **hypername, double *origin);
+
+void aster_get_superfamily(int *famin, char **name, int *nhyper,
+    char **hypername);
+
+void aster_byname_superfamily(char **name, int *nhyper, char **hypername);
+
 #endif /* ASTER_ASTER_H */
 
